==> payara-embedded-all-4.1.1.164-sources.jar: com/sun/enterprise/admin/servermgmt/pe/InstanceTimer.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 1997-2011 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package com.sun.enterprise.admin.servermgmt.pe;

public final class InstanceTimer implements Runnable
{
    private final   int             timeOutSeconds;
    private final   TimerCallback   callBack;
    private final   int             startAfterSeconds;
    private boolean                 timeOutReached;
    private long                    startTime;

    public InstanceTimer(int timeOutSeconds,
                  int startAfterSeconds,
                  TimerCallback callBack)
    {
        this.timeOutSeconds     = timeOutSeconds;
        this.startAfterSeconds  = startAfterSeconds;
        this.callBack           = callBack;
        this.timeOutReached     = false;
    }

    public void run()
    {
        startTime = System.currentTimeMillis();
        try
        {
            Thread.sleep(startAfterSeconds * 1000L);
            while (!timeOutReached() && !callBack.check())
            {
                try
                {
                    Thread.sleep(1000);
                    computeTimeOut();
                }
                catch (InterruptedException ie)
                {
                    //sLogger.warning(ie.toString());
                    timeOutReached = true;
                }
            }
        }
        catch (Exception e)
        {
            //sLogger.warning(e.toString());
            timeOutReached = true;
        }
    }

    private boolean timeOutReached()
    {
        return timeOutReached;
    }

    private void computeTimeOut()
    {
        long currentTime = System.currentTimeMillis();
        timeOutReached =
            ((currentTime - startTime) >= (timeOutSeconds * 1000L));
    }
}

==> payara-embedded-all-6.2023.12-sources.jar: com/sun/enterprise/admin/servermgmt/pe/InstanceTimer.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 1997-2011 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
// Portions Copyright [2018] Payara Foundation and/or affiliates

package com.sun.enterprise.admin.servermgmt.pe;

import java.util.logging.Level;
import java.util.logging.Logger;

/**
 * Runs a timer on an instance
 * @deprecated No known use
 */
public final class InstanceTimer implements Runnable {

    private final int timeOutSeconds;
    private final TimerCallback callBack;
    private final int startAfterSeconds;
    private boolean timeOutReached;
    private long startTime;
    
    private static final Logger LOGGER = Logger.getLogger("com.sun.enterprise.admin.servermgmt.pe");

    public InstanceTimer(int timeOutSeconds,
            int startAfterSeconds,
            TimerCallback callBack) {
        this.timeOutSeconds = timeOutSeconds;
        this.startAfterSeconds = startAfterSeconds;
        this.callBack = callBack;
        this.timeOutReached = false;
    }

    @Override
    public void run() {
        startTime = System.currentTimeMillis();
        try {
            Thread.sleep(startAfterSeconds * 1000L);
            while (!timeOutReached() && !callBack.check()) {
                try {
                    Thread.sleep(1000);
                    computeTimeOut();
                } catch (InterruptedException ie) {
                    LOGGER.log(Level.FINER, ie.toString());
                    timeOutReached = true;
                }
            }
        } catch (Exception e) {
            LOGGER.log(Level.FINER, e.toString());
            timeOutReached = true;
        }
    }

    private boolean timeOutReached() {
        return timeOutReached;
    }

    private void computeTimeOut() {
        long currentTime = System.currentTimeMillis();
        timeOutReached = ((currentTime - startTime) >= (timeOutSeconds * 1000L));
    }
}
